@@ -5,9 +5,18 @@ use Exporter;
 use Test::More;
 use FileHandle;
 use Config;
-use File::Slurp;
 use File::Temp;
 
+# http://www.cpantesters.org/cpan/report/9373ce6a-e71a-11e4-9f23-cdc1e0bfc7aa
+BEGIN {
+  $SIG{__WARN__} = sub {
+    my $warning = shift;
+    warn $warning unless $warning =~ /Subroutine .* redefined at/;
+  };
+  use File::Slurp;
+  $SIG{__WARN__} = undef;
+};
+
 use vars qw( @EXPORT @ISA $VERSION );
 
 $VERSION = sprintf "%d.%02d%02d", q/0.10.1/ =~ /(\d+)/g;
